==> osseous-2.5.0.tgz: package/README.md <==
# Osseous CSS

[![Release](https://img.shields.io/github/release/amdelamar/osseous.svg)](https://github.com/amdelamar/osseous/releases)
[![CDN](https://img.shields.io/badge/cdn-cloudflare-orange.svg)](https://austindelamar.com/osseous/)
[![License](https://img.shields.io/:license-MIT-blue.svg)](https://github.com/amdelamar/osseous/blob/master/LICENSE)

A bony CSS framework without guts.

## Download

Add to your project using this link or download the CSS file.

```html
<link rel="stylesheet" href="https://austindelamar.com/osseous/2.5.0/osseous.min.css">

<!--This tiny JavaScript file is just for the sidebar (mobile menu).-->
<script type="text/javascript" src="https://austindelamar.com/osseous/2.5.0/osseous.min.js"></script>
```

Optionally, use with subresource integrity checks like so:

```html
<!-- With SRI check: -->
<link rel="stylesheet" href="https://austindelamar.com/osseous/2.5.0/osseous.min.css" integrity="sha384-UvVzaNN7WArMkra9x0XinaXYrO9jwYrOa2UubG2VhRGWMZWpqRCtpfOOEyY4FImm" crossorigin="anonymous">
<script src="https://austindelamar.com/osseous/2.5.0/osseous.min.js" integrity="sha384-XUvewScoAT3AGDwXpY2XynuVkg8tWtyzdXKsuYWEhg+WuD8tnN2Wo+1ca1Oe5Mcl" crossorigin="anonymous"></script>
```

The links are using Cloudflare CDN for delivery. Use the [SRI Hash generator](https://www.srihash.org/) for computing integrity checks for other versions.

Or get the CSS source and minified files here: [Download ZIP | 12KB](https://github.com/amdelamar/osseous/releases/download/2.5.0/Osseous-2.5.0.zip)

Or clone this repo. `git clone https://github.com/amdelamar/osseous`

## Examples

Checkout the website for live demo and full examples: https://austindelamar.com/osseous/

## About

A project by Austin Delamar based off of [Skeleton](https://github.com/dhg/Skeleton) and other popular libraries.

If you'd like to contribute, feel free to fork and make changes, then open a pull request to `master` branch.

## License

[MIT](/LICENSE) and free forever.

==> osseous-2.5.1.tgz: package/README.md <==
# Osseous CSS

[![Release](https://img.shields.io/github/release/amdelamar/osseous.svg)](https://github.com/amdelamar/osseous/releases)
[![CDN](https://img.shields.io/badge/cdn-cloudflare-orange.svg)](https://austindelamar.com/osseous/)
[![License](https://img.shields.io/:license-MIT-blue.svg)](https://github.com/amdelamar/osseous/blob/master/LICENSE)

A bony CSS framework without guts.

## Download

Add Osseous to your web project using npm, bower, cdn link, or download the CSS file.

```
npm install osseous
bower install osseous
```

```html
<link rel="stylesheet" href="https://austindelamar.com/osseous/2.5.0/osseous.min.css">

<!--This tiny JavaScript file is just for the sidebar (mobile menu).-->
<script type="text/javascript" src="https://austindelamar.com/osseous/2.5.0/osseous.min.js"></script>
```

Optionally, use with subresource integrity checks like so:

```html
<!-- With SRI check: -->
<link rel="stylesheet" href="https://austindelamar.com/osseous/2.5.0/osseous.min.css" integrity="sha384-UvVzaNN7WArMkra9x0XinaXYrO9jwYrOa2UubG2VhRGWMZWpqRCtpfOOEyY4FImm" crossorigin="anonymous">
<script src="https://austindelamar.com/osseous/2.5.0/osseous.min.js" integrity="sha384-XUvewScoAT3AGDwXpY2XynuVkg8tWtyzdXKsuYWEhg+WuD8tnN2Wo+1ca1Oe5Mcl" crossorigin="anonymous"></script>
```

The links are using Cloudflare CDN for delivery. Use the [SRI Hash generator](https://www.srihash.org/) for computing integrity checks for other versions.

Or get the CSS source and minified files here: [Download ZIP | 12KB](https://github.com/amdelamar/osseous/releases/download/2.5.0/Osseous-2.5.0.zip)

Or clone this repo. `git clone https://github.com/amdelamar/osseous`

## Examples

Checkout the website for live demo and full examples: https://austindelamar.com/osseous/

## About

A project by Austin Delamar based off of [Skeleton](https://github.com/dhg/Skeleton) and other popular libraries.

If you'd like to contribute, feel free to fork and make changes, then open a pull request to `master` branch.

## License

[MIT](/LICENSE) and free forever.
